django\_sorcery.management.commands package
===========================================

.. automodule:: django_sorcery.management.commands
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

.. toctree::
   :maxdepth: 4

   django_sorcery.management.commands.sorcery
   django_sorcery.management.commands.sorcery_createall
   django_sorcery.management.commands.sorcery_current
   django_sorcery.management.commands.sorcery_downgrade
   django_sorcery.management.commands.sorcery_dropall
   django_sorcery.management.commands.sorcery_heads
   django_sorcery.management.commands.sorcery_history
   django_sorcery.management.commands.sorcery_revision
   django_sorcery.management.commands.sorcery_stamp
   django_sorcery.management.commands.sorcery_upgrade
